library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;

package sine_package is

  constant max_table_value_seven_bit: integer := 127;
  constant max_table_value_eight_bit: integer := 255;
  constant max_table_value_nine_bit: integer := 511;
  
  subtype table_value_type_seven_bit is integer range 0 to max_table_value_seven_bit;
  subtype table_value_type_eight_bit is integer range 0 to max_table_value_eight_bit;
  subtype table_value_type_nine_bit is integer range 0 to max_table_value_nine_bit;

  constant max_table_index_seven_bit: integer := 127;
  constant max_table_index_eight_bit: integer := 255;
  constant max_table_index_nine_bit: integer := 511;
  
  subtype table_index_type_seven_bit is integer range 0 to max_table_index_seven_bit;
  subtype table_index_type_eight_bit is integer range 0 to max_table_index_eight_bit;
  subtype table_index_type_nine_bit is integer range 0 to max_table_index_nine_bit;

  subtype sine_vector_type_seven_bit is unsigned(6 downto 0);
  subtype sine_vector_type_eight_bit is unsigned(7 downto 0);
  subtype sine_vector_type_nine_bit is unsigned(8 downto 0);

  function get_table_value_seven_bit (table_index: table_index_type_seven_bit) return table_value_type_seven_bit;
  function get_table_value_eight_bit (table_index: table_index_type_eight_bit) return table_value_type_eight_bit;
  function get_table_value_nine_bit (table_index: table_index_type_nine_bit) return table_value_type_nine_bit;
end;

package body sine_package is

  -- Seven bit index, seven bit value for zero to maximum
  function get_table_value_seven_bit (table_index: table_index_type_seven_bit) return table_value_type_seven_bit is
    variable table_value: table_value_type_seven_bit;
  begin
    case table_index is
      when 0   => table_value := 1;
      when 1   => table_value := 2;
      when 2   => table_value := 4;
      when 3   => table_value := 5;
      when 4   => table_value := 7;
      when 5   => table_value := 9;
      when 6   => table_value := 10;
      when 7   => table_value := 12;
      when 8   => table_value := 13;
      when 9   => table_value := 15;
      when 10  => table_value := 16;
      when 11  => table_value := 18;
      when 12  => table_value := 19;
      when 13  => table_value := 21;
      when 14  => table_value := 22;
      when 15  => table_value := 24;
      when 16  => table_value := 26;
      when 17  => table_value := 27;
      when 18  => table_value := 29;
      when 19  => table_value := 30;
      when 20  => table_value := 32;
      when 21  => table_value := 33;
      when 22  => table_value := 35;
      when 23  => table_value := 36;
      when 24  => table_value := 38;
      when 25  => table_value := 39;
      when 26  => table_value := 41;
      when 27  => table_value := 42;
      when 28  => table_value := 44;
      when 29  => table_value := 45;
      when 30  => table_value := 46;
      when 31  => table_value := 48;
      when 32  => table_value := 49;
      when 33  => table_value := 51;
      when 34  => table_value := 52;
      when 35  => table_value := 54;
      when 36  => table_value := 55;
      when 37  => table_value := 56;
      when 38  => table_value := 58;
      when 39  => table_value := 59;
      when 40  => table_value := 61;
      when 41  => table_value := 62;
      when 42  => table_value := 63;
      when 43  => table_value := 65;
      when 44  => table_value := 66;
      when 45  => table_value := 67;
      when 46  => table_value := 69;
      when 47  => table_value := 70;
      when 48  => table_value := 71;
      when 49  => table_value := 72;
      when 50  => table_value := 74;
      when 51  => table_value := 75;
      when 52  => table_value := 76;
      when 53  => table_value := 78;
      when 54  => table_value := 79;
      when 55  => table_value := 80;
      when 56  => table_value := 81;
      when 57  => table_value := 82;
      when 58  => table_value := 84;
      when 59  => table_value := 85;
      when 60  => table_value := 86;
      when 61  => table_value := 87;
      when 62  => table_value := 88;
      when 63  => table_value := 89;
      when 64  => table_value := 90;
      when 65  => table_value := 91;
      when 66  => table_value := 93;
      when 67  => table_value := 94;
      when 68  => table_value := 95;
      when 69  => table_value := 96;
      when 70  => table_value := 97;
      when 71  => table_value := 98;
      when 72  => table_value := 99;
      when 73  => table_value := 100;
      when 74  => table_value := 101;
      when 75  => table_value := 102;
      when 76  => table_value := 102;
      when 77  => table_value := 103;
      when 78  => table_value := 104;
      when 79  => table_value := 105;
      when 80  => table_value := 106;
      when 81  => table_value := 107;
      when 82  => table_value := 108;
      when 83  => table_value := 109;
      when 84  => table_value := 109;
      when 85  => table_value := 110;
      when 86  => table_value := 111;
      when 87  => table_value := 112;
      when 88  => table_value := 112;
      when 89  => table_value := 113;
      when 90  => table_value := 114;
      when 91  => table_value := 114;
      when 92  => table_value := 115;
      when 93  => table_value := 116;
      when 94  => table_value := 116;
      when 95  => table_value := 117;
      when 96  => table_value := 118;
      when 97  => table_value := 118;
      when 98  => table_value := 119;
      when 99  => table_value := 119;
      when 100 => table_value := 120;
      when 101 => table_value := 120;
      when 102 => table_value := 121;
      when 103 => table_value := 121;
      when 104 => table_value := 122;
      when 105 => table_value := 122;
      when 106 => table_value := 123;
      when 107 => table_value := 123;
      when 108 => table_value := 123;
      when 109 => table_value := 124;
      when 110 => table_value := 124;
      when 111 => table_value := 124;
      when 112 => table_value := 125;
      when 113 => table_value := 125;
      when 114 => table_value := 125;
      when 115 => table_value := 126;
      when 116 => table_value := 126;
      when 117 => table_value := 126;
      when 118 => table_value := 126;
      when 119 => table_value := 126;
      when 120 => table_value := 126;
      when 121 => table_value := 127;
      when 122 => table_value := 127;
      when 123 => table_value := 127;
      when 124 => table_value := 127;
      when 125 => table_value := 127;
      when 126 => table_value := 127;
      when 127 => table_value := 127;
    end case;
    return table_value;
  end;

	-- Eight bit index, eight bit value for zero to maximum
	function get_table_value_eight_bit (table_index: in table_index_type_eight_bit) return table_value_type_eight_bit is
    variable table_value	: table_value_type_eight_bit;
  begin
    case table_index is
      when 0 	=> table_value := 1;
      -- table_value := std_logic_vector (to_unsigned(1,8));
      when 1   => table_value := 2;
      when 2   => table_value := 4;
      when 3   => table_value := 5;
      when 4   => table_value := 7;
      when 5   => table_value := 9;
      when 6   => table_value := 10;
      when 7   => table_value := 12;
      when 8   => table_value := 13;
      when 9   => table_value := 15;
      when 10  => table_value := 16;
      when 11  => table_value := 18;
      when 12  => table_value := 20;
      when 13  => table_value := 21;
      when 14  => table_value := 23;
      when 15  => table_value := 24;
      when 16  => table_value := 26;
      when 17  => table_value := 27;
      when 18  => table_value := 29;
      when 19  => table_value := 30;
      when 20  => table_value := 32;
      when 21  => table_value := 34;
      when 22  => table_value := 35;
      when 23  => table_value := 37;
      when 24  => table_value := 38;
      when 25  => table_value := 40;
      when 26  => table_value := 41;
      when 27  => table_value := 43;
      when 28  => table_value := 44;
      when 29  => table_value := 46;
      when 30  => table_value := 47;
      when 31  => table_value := 49;
      when 32  => table_value := 51;
      when 33  => table_value := 52;
      when 34  => table_value := 54;
      when 35  => table_value := 55;
      when 36  => table_value := 57;
      when 37  => table_value := 58;
      when 38  => table_value := 60;
      when 39  => table_value := 61;
      when 40  => table_value := 63;
      when 41  => table_value := 64;
      when 42  => table_value := 66;
      when 43  => table_value := 67;
      when 44  => table_value := 69;
      when 45  => table_value := 70;
      when 46  => table_value := 72;
      when 47  => table_value := 73;
      when 48  => table_value := 75;
      when 49  => table_value := 76;
      when 50  => table_value := 78;
      when 51  => table_value := 79;
      when 52  => table_value := 81;
      when 53  => table_value := 84;
	  when 54  => table_value := 84;
      when 55  => table_value := 85;
      when 56  => table_value := 87;
      when 57  => table_value := 88;
      when 58  => table_value := 90;
      when 59  => table_value := 91;
      when 60  => table_value := 93;
      when 61  => table_value := 94;
      when 62  => table_value := 95;
      when 63  => table_value := 97;
      when 64  => table_value := 98;
      when 65  => table_value := 100;
      when 66  => table_value := 101;
      when 67  => table_value := 103;
      when 68  => table_value := 104;
      when 69  => table_value := 105;
      when 70  => table_value := 107;
      when 71  => table_value := 108;
      when 72  => table_value := 110;
      when 73  => table_value := 111;
      when 74  => table_value := 113;
      when 75  => table_value := 114;
      when 76  => table_value := 115;
      when 77  => table_value := 117;
      when 78  => table_value := 118;
      when 79  => table_value := 120;
      when 80  => table_value := 121;
      when 81  => table_value := 122;
      when 82  => table_value := 124;
      when 83  => table_value := 125;
      when 84  => table_value := 126;
      when 85  => table_value := 128;
      when 86  => table_value := 129;
      when 87  => table_value := 130;
      when 88  => table_value := 132;
      when 89  => table_value := 133;
      when 90  => table_value := 134;
      when 91  => table_value := 136;
      when 92  => table_value := 137;
      when 93  => table_value := 138;
      when 94  => table_value := 140;
      when 95  => table_value := 141;
      when 96  => table_value := 142;
      when 97  => table_value := 144;
      when 98  => table_value := 145;
      when 99  => table_value := 146;
      when 100 => table_value := 147;
      when 101 => table_value := 149;
      when 102 => table_value := 150;
      when 103 => table_value := 151;
      when 104 => table_value := 153;
      when 105 => table_value := 154;
      when 106 => table_value := 155;
      when 107 => table_value := 156;
      when 108 => table_value := 158;
      when 109 => table_value := 159;
      when 110 => table_value := 160;
      when 111 => table_value := 161;
      when 112 => table_value := 162;
      when 113 => table_value := 164;
      when 114 => table_value := 165;
      when 115 => table_value := 166;
      when 116 => table_value := 167;
      when 117 => table_value := 168;
      when 118 => table_value := 170;
      when 119 => table_value := 171;
      when 120 => table_value := 172;
      when 121 => table_value := 173;
      when 122 => table_value := 174;
      when 123 => table_value := 175;
      when 124 => table_value := 176;
      when 125 => table_value := 178;
      when 126 => table_value := 179;
      when 127 => table_value := 180;
      when 128 => table_value := 181;
      when 129 => table_value := 182;
      when 130 => table_value := 183;
      when 131 => table_value := 184;
      when 132 => table_value := 185;
      when 133 => table_value := 186;
      when 134 => table_value := 187;
      when 135 => table_value := 188;
      when 136 => table_value := 189;
      when 137 => table_value := 191;
      when 138 => table_value := 192;
      when 139 => table_value := 193;
      when 140 => table_value := 194;
      when 141 => table_value := 195;
      when 142 => table_value := 196;
      when 143 => table_value := 197;
      when 144 => table_value := 198;
      when 145 => table_value := 199;
      when 146 => table_value := 200;
      when 147 => table_value := 201;
      when 148 => table_value := 202;
      when 149 => table_value := 202;
      when 150 => table_value := 203;
      when 151 => table_value := 204;
      when 152 => table_value := 205;
      when 153 => table_value := 206;
      when 154 => table_value := 207;
      when 155 => table_value := 208;
      when 156 => table_value := 209;
      when 157 => table_value := 210;
      when 158 => table_value := 211;
      when 159 => table_value := 212;
      when 160 => table_value := 212;
      when 161 => table_value := 213;
      when 162 => table_value := 214;
      when 163 => table_value := 215;
      when 164 => table_value := 216;
      when 165 => table_value := 217;
      when 166 => table_value := 218;
      when 167 => table_value := 218;
      when 168 => table_value := 219;
      when 169 => table_value := 220;
      when 170 => table_value := 221;
      when 171 => table_value := 221;
      when 172 => table_value := 222;
      when 173 => table_value := 223;
      when 174 => table_value := 224;
      when 175 => table_value := 225;
      when 176 => table_value := 225;
      when 177 => table_value := 226;
      when 178 => table_value := 227;
      when 179 => table_value := 227;
      when 180 => table_value := 228;
      when 181 => table_value := 229;
      when 182 => table_value := 230;
      when 183 => table_value := 230;
      when 184 => table_value := 231;
      when 185 => table_value := 232;
      when 186 => table_value := 232;
      when 187 => table_value := 233;
      when 188 => table_value := 233;
      when 189 => table_value := 234;
      when 190 => table_value := 235;
      when 191 => table_value := 235;
      when 192 => table_value := 236;
      when 193 => table_value := 236;
      when 194 => table_value := 237;
      when 195 => table_value := 238;
      when 196 => table_value := 238;
      when 197 => table_value := 239;
      when 198 => table_value := 239;
      when 199 => table_value := 240;
      when 200 => table_value := 240;
      when 201 => table_value := 241;
      when 202 => table_value := 241;
      when 203 => table_value := 242;
      when 204 => table_value := 242;
      when 205 => table_value := 243;
      when 206 => table_value := 243;
      when 207 => table_value := 244;
      when 208 => table_value := 244;
      when 209 => table_value := 245;
      when 210 => table_value := 245;
      when 211 => table_value := 246;
      when 212 => table_value := 246;
      when 213 => table_value := 246;
      when 214 => table_value := 247;
      when 215 => table_value := 247;
      when 216 => table_value := 248;
      when 217 => table_value := 248;
      when 218 => table_value := 248;
      when 219 => table_value := 249;
      when 220 => table_value := 249;
      when 221 => table_value := 249;
      when 222 => table_value := 250;
      when 223 => table_value := 250;
      when 224 => table_value := 250;
      when 225 => table_value := 251;
      when 226 => table_value := 251;
      when 227 => table_value := 251;
      when 228 => table_value := 251;
      when 229 => table_value := 252;
      when 230 => table_value := 252;
      when 231 => table_value := 252;
      when 232 => table_value := 252;
      when 233 => table_value := 253;
      when 234 => table_value := 253;
      when 235 => table_value := 253;
      when 236 => table_value := 253;
      when 237 => table_value := 253;
      when 238 => table_value := 254;
      when 239 => table_value := 254;
      when 240 => table_value := 254;
      when 241 => table_value := 254;
      when 242 => table_value := 254;
      when 243 => table_value := 254;
      when 244 => table_value := 254;
      when 245 => table_value := 254;
      when 246 => table_value := 255;
      when 247 => table_value := 255;
      when 248 => table_value := 255;
      when 249 => table_value := 255;
      when 250 => table_value := 255;
      when 251 => table_value := 255;
      when 252 => table_value := 255;
      when 253 => table_value := 255;
      when 254 => table_value := 255;
      when 255 => table_value := 255;
    end case;
    return table_value;
  end;
  
  
	-- Nine bit index, nine bit value for zero to maximum
	function get_table_value_nine_bit (table_index: table_index_type_nine_bit) return table_value_type_nine_bit is
    variable table_value: table_value_type_nine_bit;
  begin
    case table_index is
      when 0   => table_value := 1;
      when 1   => table_value := 2;
      when 2   => table_value := 4;
      when 3   => table_value := 5;
      when 4   => table_value := 7;
      when 5   => table_value := 9;
      when 6   => table_value := 10;
      when 7   => table_value := 12;
      when 8   => table_value := 13;
      when 9   => table_value := 15;
      when 10  => table_value := 16;
      when 11  => table_value := 18;
      when 12  => table_value := 20;
      when 13  => table_value := 21;
      when 14  => table_value := 23;
      when 15  => table_value := 24;
      when 16  => table_value := 26;
      when 17  => table_value := 27;
      when 18  => table_value := 29;
      when 19  => table_value := 31;
      when 20  => table_value := 32;
      when 21  => table_value := 34;
      when 22  => table_value := 35;
      when 23  => table_value := 37;
      when 24  => table_value := 38;
      when 25  => table_value := 40;
      when 26  => table_value := 41;
      when 27  => table_value := 43;
      when 28  => table_value := 45;
      when 29  => table_value := 46;
      when 30  => table_value := 48;
      when 31  => table_value := 49;
      when 32  => table_value := 51;
      when 33  => table_value := 52;
      when 34  => table_value := 54;
      when 35  => table_value := 56;
      when 36  => table_value := 57;
      when 37  => table_value := 59;
      when 38  => table_value := 60;
      when 39  => table_value := 62;
      when 40  => table_value := 63;
      when 41  => table_value := 65;
      when 42  => table_value := 66;
      when 43  => table_value := 68;
      when 44  => table_value := 70;
      when 45  => table_value := 71;
      when 46  => table_value := 73;
      when 47  => table_value := 74;
      when 48  => table_value := 76;
      when 49  => table_value := 77;
      when 50  => table_value := 79;
      when 51  => table_value := 80;
      when 52  => table_value := 82;
      when 53  => table_value := 83;
      when 54  => table_value := 85;
      when 55  => table_value := 87;
      when 56  => table_value := 88;
      when 57  => table_value := 90;
      when 58  => table_value := 91;
      when 59  => table_value := 93;
      when 60  => table_value := 94;
      when 61  => table_value := 96;
      when 62  => table_value := 97;
      when 63  => table_value := 99;
      when 64  => table_value := 100;
      when 65  => table_value := 102;
      when 66  => table_value := 104;
      when 67  => table_value := 105;
      when 68  => table_value := 107;
      when 69  => table_value := 108;
      when 70  => table_value := 110;
      when 71  => table_value := 111;
      when 72  => table_value := 113;
      when 73  => table_value := 114;
      when 74  => table_value := 116;
      when 75  => table_value := 117;
      when 76  => table_value := 119;
      when 77  => table_value := 120;
      when 78  => table_value := 122;
      when 79  => table_value := 123;
      when 80  => table_value := 125;
      when 81  => table_value := 126;
      when 82  => table_value := 128;
      when 83  => table_value := 129;
      when 84  => table_value := 131;
      when 85  => table_value := 133;
      when 86  => table_value := 134;
      when 87  => table_value := 136;
      when 88  => table_value := 137;
      when 89  => table_value := 139;
      when 90  => table_value := 140;
      when 91  => table_value := 142;
      when 92  => table_value := 143;
      when 93  => table_value := 145;
      when 94  => table_value := 146;
      when 95  => table_value := 148;
      when 96  => table_value := 149;
      when 97  => table_value := 151;
      when 98  => table_value := 152;
      when 99  => table_value := 154;
      when 100 => table_value := 155;
      when 101 => table_value := 157;
      when 102 => table_value := 158;
      when 103 => table_value := 160;
      when 104 => table_value := 161;
      when 105 => table_value := 163;
      when 106 => table_value := 164;
      when 107 => table_value := 165;
      when 108 => table_value := 167;
      when 109 => table_value := 168;
      when 110 => table_value := 170;
      when 111 => table_value := 171;
      when 112 => table_value := 173;
      when 113 => table_value := 174;
      when 114 => table_value := 176;
      when 115 => table_value := 177;
      when 116 => table_value := 179;
      when 117 => table_value := 180;
      when 118 => table_value := 182;
      when 119 => table_value := 183;
      when 120 => table_value := 185;
      when 121 => table_value := 186;
      when 122 => table_value := 188;
      when 123 => table_value := 189;
      when 124 => table_value := 190;
      when 125 => table_value := 192;
      when 126 => table_value := 193;
      when 127 => table_value := 195;
      when 128 => table_value := 196;
      when 129 => table_value := 198;
      when 130 => table_value := 199;
      when 131 => table_value := 201;
      when 132 => table_value := 202;
      when 133 => table_value := 203;
      when 134 => table_value := 205;
      when 135 => table_value := 206;
      when 136 => table_value := 208;
      when 137 => table_value := 209;
      when 138 => table_value := 211;
      when 139 => table_value := 212;
      when 140 => table_value := 214;
      when 141 => table_value := 215;
      when 142 => table_value := 216;
      when 143 => table_value := 218;
      when 144 => table_value := 219;
      when 145 => table_value := 221;
      when 146 => table_value := 222;
      when 147 => table_value := 223;
      when 148 => table_value := 225;
      when 149 => table_value := 226;
      when 150 => table_value := 228;
      when 151 => table_value := 229;
      when 152 => table_value := 230;
      when 153 => table_value := 232;
      when 154 => table_value := 233;
      when 155 => table_value := 235;
      when 156 => table_value := 236;
      when 157 => table_value := 237;
      when 158 => table_value := 239;
      when 159 => table_value := 240;
      when 160 => table_value := 242;
      when 161 => table_value := 243;
      when 162 => table_value := 244;
      when 163 => table_value := 246;
      when 164 => table_value := 247;
      when 165 => table_value := 248;
      when 166 => table_value := 250;
      when 167 => table_value := 251;
      when 168 => table_value := 253;
      when 169 => table_value := 254;
      when 170 => table_value := 255;
      when 171 => table_value := 257;
      when 172 => table_value := 258;
      when 173 => table_value := 259;
      when 174 => table_value := 261;
      when 175 => table_value := 262;
      when 176 => table_value := 263;
      when 177 => table_value := 265;
      when 178 => table_value := 266;
      when 179 => table_value := 267;
      when 180 => table_value := 269;
      when 181 => table_value := 270;
      when 182 => table_value := 271;
      when 183 => table_value := 273;
      when 184 => table_value := 274;
      when 185 => table_value := 275;
      when 186 => table_value := 277;
      when 187 => table_value := 278;
      when 188 => table_value := 279;
      when 189 => table_value := 281;
      when 190 => table_value := 282;
      when 191 => table_value := 283;
      when 192 => table_value := 285;
      when 193 => table_value := 286;
      when 194 => table_value := 287;
      when 195 => table_value := 288;
      when 196 => table_value := 290;
      when 197 => table_value := 291;
      when 198 => table_value := 292;
      when 199 => table_value := 294;
      when 200 => table_value := 295;
      when 201 => table_value := 296;
      when 202 => table_value := 297;
      when 203 => table_value := 299;
      when 204 => table_value := 300;
      when 205 => table_value := 301;
      when 206 => table_value := 303;
      when 207 => table_value := 304;
      when 208 => table_value := 305;
      when 209 => table_value := 306;
      when 210 => table_value := 308;
      when 211 => table_value := 309;
      when 212 => table_value := 310;
      when 213 => table_value := 311;
      when 214 => table_value := 313;
      when 215 => table_value := 314;
      when 216 => table_value := 315;
      when 217 => table_value := 316;
      when 218 => table_value := 317;
      when 219 => table_value := 319;
      when 220 => table_value := 320;
      when 221 => table_value := 321;
      when 222 => table_value := 322;
      when 223 => table_value := 324;
      when 224 => table_value := 325;
      when 225 => table_value := 326;
      when 226 => table_value := 327;
      when 227 => table_value := 328;
      when 228 => table_value := 330;
      when 229 => table_value := 331;
      when 230 => table_value := 332;
      when 231 => table_value := 333;
      when 232 => table_value := 334;
      when 233 => table_value := 336;
      when 234 => table_value := 337;
      when 235 => table_value := 338;
      when 236 => table_value := 339;
      when 237 => table_value := 340;
      when 238 => table_value := 341;
      when 239 => table_value := 343;
      when 240 => table_value := 344;
      when 241 => table_value := 345;
      when 242 => table_value := 346;
      when 243 => table_value := 347;
      when 244 => table_value := 348;
      when 245 => table_value := 350;
      when 246 => table_value := 351;
      when 247 => table_value := 352;
      when 248 => table_value := 353;
      when 249 => table_value := 354;
      when 250 => table_value := 355;
      when 251 => table_value := 356;
      when 252 => table_value := 357;
      when 253 => table_value := 359;
      when 254 => table_value := 360;
      when 255 => table_value := 361;
      when 256 => table_value := 362;
      when 257 => table_value := 363;
      when 258 => table_value := 364;
      when 259 => table_value := 365;
      when 260 => table_value := 366;
      when 261 => table_value := 367;
      when 262 => table_value := 368;
      when 263 => table_value := 370;
      when 264 => table_value := 371;
      when 265 => table_value := 372;
      when 266 => table_value := 373;
      when 267 => table_value := 374;
      when 268 => table_value := 375;
      when 269 => table_value := 376;
      when 270 => table_value := 377;
      when 271 => table_value := 378;
      when 272 => table_value := 379;
      when 273 => table_value := 380;
      when 274 => table_value := 381;
      when 275 => table_value := 382;
      when 276 => table_value := 383;
      when 277 => table_value := 384;
      when 278 => table_value := 385;
      when 279 => table_value := 386;
      when 280 => table_value := 387;
      when 281 => table_value := 388;
      when 282 => table_value := 389;
      when 283 => table_value := 390;
      when 284 => table_value := 392;
      when 285 => table_value := 393;
      when 286 => table_value := 394;
      when 287 => table_value := 395;
      when 288 => table_value := 396;
      when 289 => table_value := 396;
      when 290 => table_value := 397;
      when 291 => table_value := 398;
      when 292 => table_value := 399;
      when 293 => table_value := 400;
      when 294 => table_value := 401;
      when 295 => table_value := 402;
      when 296 => table_value := 403;
      when 297 => table_value := 404;
      when 298 => table_value := 405;
      when 299 => table_value := 406;
      when 300 => table_value := 407;
      when 301 => table_value := 408;
      when 302 => table_value := 409;
      when 303 => table_value := 410;
      when 304 => table_value := 411;
      when 305 => table_value := 412;
      when 306 => table_value := 413;
      when 307 => table_value := 414;
      when 308 => table_value := 415;
      when 309 => table_value := 416;
      when 310 => table_value := 416;
      when 311 => table_value := 417;
      when 312 => table_value := 418;
      when 313 => table_value := 419;
      when 314 => table_value := 420;
      when 315 => table_value := 421;
      when 316 => table_value := 422;
      when 317 => table_value := 423;
      when 318 => table_value := 424;
      when 319 => table_value := 424;
      when 320 => table_value := 425;
      when 321 => table_value := 426;
      when 322 => table_value := 427;
      when 323 => table_value := 428;
      when 324 => table_value := 429;
      when 325 => table_value := 430;
      when 326 => table_value := 430;
      when 327 => table_value := 431;
      when 328 => table_value := 432;
      when 329 => table_value := 433;
      when 330 => table_value := 434;
      when 331 => table_value := 435;
      when 332 => table_value := 435;
      when 333 => table_value := 436;
      when 334 => table_value := 437;
      when 335 => table_value := 438;
      when 336 => table_value := 439;
      when 337 => table_value := 440;
      when 338 => table_value := 440;
      when 339 => table_value := 441;
      when 340 => table_value := 442;
      when 341 => table_value := 443;
      when 342 => table_value := 443;
      when 343 => table_value := 444;
      when 344 => table_value := 445;
      when 345 => table_value := 446;
      when 346 => table_value := 447;
      when 347 => table_value := 447;
      when 348 => table_value := 448;
      when 349 => table_value := 449;
      when 350 => table_value := 450;
      when 351 => table_value := 450;
      when 352 => table_value := 451;
      when 353 => table_value := 452;
      when 354 => table_value := 452;
      when 355 => table_value := 453;
      when 356 => table_value := 454;
      when 357 => table_value := 455;
      when 358 => table_value := 455;
      when 359 => table_value := 456;
      when 360 => table_value := 457;
      when 361 => table_value := 457;
      when 362 => table_value := 458;
      when 363 => table_value := 459;
      when 364 => table_value := 460;
      when 365 => table_value := 460;
      when 366 => table_value := 461;
      when 367 => table_value := 462;
      when 368 => table_value := 462;
      when 369 => table_value := 463;
      when 370 => table_value := 464;
      when 371 => table_value := 464;
      when 372 => table_value := 465;
      when 373 => table_value := 466;
      when 374 => table_value := 466;
      when 375 => table_value := 467;
      when 376 => table_value := 467;
      when 377 => table_value := 468;
      when 378 => table_value := 469;
      when 379 => table_value := 469;
      when 380 => table_value := 470;
      when 381 => table_value := 471;
      when 382 => table_value := 471;
      when 383 => table_value := 472;
      when 384 => table_value := 472;
      when 385 => table_value := 473;
      when 386 => table_value := 474;
      when 387 => table_value := 474;
      when 388 => table_value := 475;
      when 389 => table_value := 475;
      when 390 => table_value := 476;
      when 391 => table_value := 476;
      when 392 => table_value := 477;
      when 393 => table_value := 478;
      when 394 => table_value := 478;
      when 395 => table_value := 479;
      when 396 => table_value := 479;
      when 397 => table_value := 480;
      when 398 => table_value := 480;
      when 399 => table_value := 481;
      when 400 => table_value := 481;
      when 401 => table_value := 482;
      when 402 => table_value := 482;
      when 403 => table_value := 483;
      when 404 => table_value := 483;
      when 405 => table_value := 484;
      when 406 => table_value := 484;
      when 407 => table_value := 485;
      when 408 => table_value := 485;
      when 409 => table_value := 486;
      when 410 => table_value := 486;
      when 411 => table_value := 487;
      when 412 => table_value := 487;
      when 413 => table_value := 488;
      when 414 => table_value := 488;
      when 415 => table_value := 489;
      when 416 => table_value := 489;
      when 417 => table_value := 490;
      when 418 => table_value := 490;
      when 419 => table_value := 491;
      when 420 => table_value := 491;
      when 421 => table_value := 491;
      when 422 => table_value := 492;
      when 423 => table_value := 492;
      when 424 => table_value := 493;
      when 425 => table_value := 493;
      when 426 => table_value := 494;
      when 427 => table_value := 494;
      when 428 => table_value := 494;
      when 429 => table_value := 495;
      when 430 => table_value := 495;
      when 431 => table_value := 495;
      when 432 => table_value := 496;
      when 433 => table_value := 496;
      when 434 => table_value := 497;
      when 435 => table_value := 497;
      when 436 => table_value := 497;
      when 437 => table_value := 498;
      when 438 => table_value := 498;
      when 439 => table_value := 498;
      when 440 => table_value := 499;
      when 441 => table_value := 499;
      when 442 => table_value := 499;
      when 443 => table_value := 500;
      when 444 => table_value := 500;
      when 445 => table_value := 500;
      when 446 => table_value := 501;
      when 447 => table_value := 501;
      when 448 => table_value := 501;
      when 449 => table_value := 502;
      when 450 => table_value := 502;
      when 451 => table_value := 502;
      when 452 => table_value := 503;
      when 453 => table_value := 503;
      when 454 => table_value := 503;
      when 455 => table_value := 503;
      when 456 => table_value := 504;
      when 457 => table_value := 504;
      when 458 => table_value := 504;
      when 459 => table_value := 504;
      when 460 => table_value := 505;
      when 461 => table_value := 505;
      when 462 => table_value := 505;
      when 463 => table_value := 505;
      when 464 => table_value := 506;
      when 465 => table_value := 506;
      when 466 => table_value := 506;
      when 467 => table_value := 506;
      when 468 => table_value := 506;
      when 469 => table_value := 507;
      when 470 => table_value := 507;
      when 471 => table_value := 507;
      when 472 => table_value := 507;
      when 473 => table_value := 507;
      when 474 => table_value := 508;
      when 475 => table_value := 508;
      when 476 => table_value := 508;
      when 477 => table_value := 508;
      when 478 => table_value := 508;
      when 479 => table_value := 508;
      when 480 => table_value := 509;
      when 481 => table_value := 509;
      when 482 => table_value := 509;
      when 483 => table_value := 509;
      when 484 => table_value := 509;
      when 485 => table_value := 509;
      when 486 => table_value := 509;
      when 487 => table_value := 510;
      when 488 => table_value := 510;
      when 489 => table_value := 510;
      when 490 => table_value := 510;
      when 491 => table_value := 510;
      when 492 => table_value := 510;
      when 493 => table_value := 510;
      when 494 => table_value := 510;
      when 495 => table_value := 510;
      when 496 => table_value := 510;
      when 497 => table_value := 510;
      when 498 => table_value := 511;
      when 499 => table_value := 511;
      when 500 => table_value := 511;
      when 501 => table_value := 511;
      when 502 => table_value := 511;
      when 503 => table_value := 511;
      when 504 => table_value := 511;
      when 505 => table_value := 511;
      when 506 => table_value := 511;
      when 507 => table_value := 511;
      when 508 => table_value := 511;
      when 509 => table_value := 511;
      when 510 => table_value := 511;
      when 511 => table_value := 511;
    end case;
    return table_value;
  end;


end; -- package

