library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;

entity sekunden_takt is
generic (teiler : positive := 500);


port (
		clock 	: in std_logic;		-- Systemclock Pin
		takt  	: out std_logic
	  );
end sekunden_takt;

architecture sekunden_takt_rtl of sekunden_takt is
	signal zaehler : integer range 0 to teiler := 0;
	type states is (one, two);
	signal state : states;
begin
	
	 process (clock)
	 begin
		if rising_edge(clock)
		then
			case state is
				when one =>		if zaehler < teiler
									then 
										takt <= '0';
										zaehler <= zaehler + 1;
									else
										state <= two;
									end if;
				when two =>   	takt <= '1';
									zaehler <= 0;
									state <= one;
								
			end case;
      end if;
    end process;
end sekunden_takt_rtl;	  


------------------------------------------------------------------------------------------

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;
use work.sine_package.all;

entity sine_wave is
  port( 
			clock 	: in std_logic;
			reset 	: in std_logic;
			enable	: in std_logic;
			-- wave_out als signed eight bit
			wave_out	: out signed(7 downto 0)
		);
end entity sine_wave;

architecture arch1 of sine_wave is
  type state_type is ( counting_up, change_down, counting_down, change_up );
  signal state, next_state: state_type;
  signal table_index: table_index_type_seven_bit;
  signal positive_cycle: boolean;
begin

  process(clock, reset)
  begin
    if reset = '1' 
	 then
      state <= counting_up;
    elsif rising_edge(clock) 
	 then
      if enable = '1' 
		then
        state <= next_state;
      end if;
    end if;
  end process;

  process(state, table_index)
  begin
    next_state <= state;
    case state is
      when counting_up =>
        if table_index = max_table_index_seven_bit 
		  then
          next_state <= change_down;
        end if;
      when change_down =>
        next_state <= counting_down;
      when counting_down =>
        if table_index = 0 
		  then
          next_state <= change_up;
        end if;
      when others => -- change_up
        next_state <= counting_up;
    end case;
  end process;

  process(clock, reset)
  begin
    if reset = '1' 
	 then
      table_index <= 0;
      positive_cycle <= true;
    elsif rising_edge( clock ) 
	 then
      if enable = '1' 
		then
        case next_state is
          when counting_up =>
            table_index <= table_index + 1;
          when counting_down =>
            table_index <= table_index - 1;
          when change_up =>
            positive_cycle <= not positive_cycle;
          when others =>
            -- nothing to do
        end case;
      end if;
    end if;
  end process;

  process(table_index, positive_cycle)
    variable table_value: table_value_type_seven_bit;
  begin
    table_value := get_table_value_seven_bit(table_index);
	 -- Konvertierung von unsigned seven bit in signed eight bit
    if positive_cycle 
	 then
      wave_out <= to_signed(table_value,sine_vector_type_seven_bit'length+1);
    else
      wave_out <= to_signed(-table_value,sine_vector_type_seven_bit'length+1);
    end if;
  end process;

end architecture arch1;


-----------------------------------------------------------------------------------------------------


library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;
use work.sine_package.all;

entity adc_out is
	port (
			clock 		: in std_logic;
			SPI_SCK  	: out std_logic;
			SPI_MOSI 	: out std_logic;
			DAC_CLR  	: out std_logic;
			DAC_CS      : out std_logic;
			BTN_SOUTH 	: in std_logic;
			BTN_EAST  	: in std_logic
			);
end entity adc_out;

architecture rtl of adc_out is
	
	component sekunden_takt
	port
	(
			clock : in std_logic;
			takt  : out std_logic
	);
	end component sekunden_takt;
	
	component sine_wave
	port
	(
			clock 	: in std_logic;
			reset 	: in std_logic;
			enable	: in std_logic;
			-- Signed eight bit
			wave_out	: out signed(7 downto 0)
	);
	end component sine_wave;
	
	
	type dacStateType is (idle, sendBit, clockHigh, csHigh);
	signal dacState   : dacStateType := idle;
	signal enable     : std_logic := '1';
	signal wave_out   : signed(7 downto 0);
	signal output     : unsigned(11 downto 0);
	-- 32 Bit Format
	signal dacCounter : integer range 0 to 31;
	signal DAC_OUT    : unsigned(31 downto 0);
   signal takt  : std_logic;
	
begin

   takt_teiler : sekunden_takt
	port map
	(
		clock => clock,
		takt  => takt
	);
	
	sine : sine_wave
	port map
	(
		clock => clock,
		reset => BTN_EAST,
		enable => enable,
		wave_out => wave_out
	);
	
	process (clock, BTN_SOUTH)
	begin
		if rising_edge(clock)
		then
			if BTN_SOUTH = '1'
			then
				enable <= not enable;
			end if;
		end if;
	end process;
	
	
	process(clock, enable)
   begin
	  if enable = '0' 
	  then
            dacState <= idle;
     elsif rising_edge(clock) 
	  then
			-- wave_out is signed eight bit
			output <= unsigned(wave_out) & "0000";
			-- transfer data to DAC every us
			case dacState is
				 when idle =>
					  if takt = '1' 
					  then
							DAC_CS <= '0';
							SPI_SCK <= '0';
							dacState <= sendBit;
							dacCounter <= 31;
							-- DAC_OUT <= "0010" & "1111" & output & "00000000";
							-- 32 Bit Format 
							-- 4Bit Dont care & output & Address & Command & 8Bit Dont care
							DAC_OUT <= "0000" & output & "1111" & "0011" & "00000000";
					  end if;
				 when sendBit =>
					  SPI_SCK <= '0';
					  -- SPI_MOSI <= DAC_OUT(23);
					  SPI_MOSI <= DAC_OUT(31);
					  DAC_OUT <= DAC_OUT(30 downto 0) & "0";
					  dacState <= clockHigh;
				 when clockHigh =>
					  SPI_SCK <= '1';
					  if dacCounter = 0 
					  then
							dacState <= csHigh;
					  else
							dacCounter <= dacCounter - 1;
							dacState <= sendBit;
					  end if;
				 when csHigh =>
					  DAC_CS <= '1';
					  dacState <= idle;
			end case;
		end if;
	end process;
		
	DAC_CLR <= '1';
		
end architecture rtl;